# 💱 Currency Conveter Api

Simplest currency converter with pure python with CurrecnyConverterApi

## 🔑  Get Your Free Api Key

- Click the link: https://free.currencyconverterapi.com/free-api-key
- Type your e-mail
- Verify your email and use the key that send to your e-mail

## 🪪  License

```
Copyright 2022 Yunus Emre Ak ~ YEmreAk.com

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
